@@ -38,13 +38,13 @@
 #include <KIO/UDSEntry>
 #include <KJobWidgets>
 #include <KLocalizedString>
-#include <KNotificationRestrictions>
 #include <KProtocolInfo>
 #include <KSharedConfig>
 #include <KSqueezedTextLabel>
 #include <KToggleFullScreenAction>
 #include <KToolBar>
 #include <KXMLGUIFactory>
+#include <kio_version.h>
 
 #include <phonon/BackendCapabilities>
 #include <phonon/VideoWidget>
@@ -84,7 +84,6 @@ MainWindow::MainWindow()
     , m_timeLabel(nullptr)
     , m_titleLabel(new QLabel(this))
     , m_menuToggleAction(nullptr)
-    , m_stopScreenSaver(nullptr)
     , m_stopSleepCookie(-1)
     , m_stopScreenPowerMgmtCookie(-1)
     , m_profileMaxDays(30)
@@ -260,7 +259,8 @@ MainWindow::~MainWindow()
 {
     hide(); // so we appear to have quit, and then sound fades out below
     releasePowerSave();
-    qobject_cast<KRecentFilesAction *>(action("file_open_recent"))->saveEntries(KConfigGroup(KSharedConfig::openConfig(), "General"));
+    qobject_cast<KRecentFilesAction *>(action(QStringLiteral("file_open_recent")))
+        ->saveEntries(KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General")));
     delete videoWindow(); // fades out sound in dtor
 }
 
@@ -300,7 +300,7 @@ void MainWindow::setupActions()
     open->setText(i18nc("@action", "Play File…"));
     open->setToolTip(i18nc("@info:tooltip", "Open a media file for playback"));
     auto recent = KStandardAction::openRecent(this, &MainWindow::open, ac);
-    recent->loadEntries(KConfigGroup(KSharedConfig::openConfig(), "General"));
+    recent->loadEntries(KConfigGroup(KSharedConfig::openConfig(), QStringLiteral("General")));
     KStandardAction::quit(qApp, &QApplication::closeAllWindows, ac);
 
     const auto addToAc = [ac](QAction *action) {
@@ -389,7 +389,7 @@ void MainWindow::setupActions()
                                     ac);
     uniqueToggle->setObjectName(QLatin1String("unique"));
     uniqueToggle->setCheckable(true);
-    uniqueToggle->setChecked(!KSharedConfig::openConfig()->group("KDE").readEntry("MultipleInstances", QVariant(false)).toBool());
+    uniqueToggle->setChecked(!KSharedConfig::openConfig()->group(QStringLiteral("KDE")).readEntry("MultipleInstances", QVariant(false)).toBool());
     connect(uniqueToggle, &QAction::toggled, this, &MainWindow::toggleUnique);
     addToAc(uniqueToggle);
 
@@ -435,7 +435,7 @@ void MainWindow::setupActions()
 void MainWindow::toggleUnique(bool unique)
 {
     KSharedConfig::Ptr cfg = KSharedConfig::openConfig(); // kf5 FIXME? this might not work w/o KUniqueApplication
-    cfg->group("KDE").writeEntry("MultipleInstances", !unique);
+    cfg->group(QStringLiteral("KDE")).writeEntry("MultipleInstances", !unique);
     cfg->sync();
 }
 
@@ -456,12 +456,12 @@ void MainWindow::toggleVideoSettings(bool show)
         m_sliders.clear();
         m_sliders << ui.brightnessSlider << ui.contrastSlider << ui.hueSlider << ui.saturationSlider;
         updateSliders();
-        for (QSlider *slider : qAsConst(m_sliders)) {
+        for (QSlider *slider : std::as_const(m_sliders)) {
             connect(slider, &QAbstractSlider::valueChanged, engine(), &VideoWindow::settingChanged);
         }
 
         connect(ui.defaultsButton, &QAbstractButton::clicked, this, &MainWindow::restoreDefaultVideoSettings);
-        connect(ui.closeButton, &QAbstractButton::clicked, action("video_settings"), &QAction::setChecked);
+        connect(ui.closeButton, &QAbstractButton::clicked, action(QStringLiteral("video_settings")), &QAction::setChecked);
         connect(ui.closeButton, &QAbstractButton::clicked, m_leftDock, &QObject::deleteLater);
     } else {
         m_sliders.clear();
@@ -471,7 +471,7 @@ void MainWindow::toggleVideoSettings(bool show)
 
 void MainWindow::restoreDefaultVideoSettings()
 {
-    for (QSlider *slider : qAsConst(m_sliders)) {
+    for (QSlider *slider : std::as_const(m_sliders)) {
         slider->setValue(0);
     }
 }
@@ -544,7 +544,7 @@ void MainWindow::stop()
 
 void MainWindow::updateSliders()
 {
-    for (QSlider *slider : qAsConst(m_sliders)) {
+    for (QSlider *slider : std::as_const(m_sliders)) {
         slider->setValue(engine()->videoSetting(slider->objectName()));
     }
 }
@@ -600,7 +600,7 @@ bool MainWindow::load(const QUrl &url)
     // check if an UDS_LOCAL_PATH is defined.
     if (!ret && KProtocolInfo::protocolClass(url.scheme()) == QLatin1String(":local")) {
         // #define UDS_LOCAL_PATH (7 | KIO::UDS_STRING)
-        KIO::StatJob *job = KIO::statDetails(url, KIO::StatJob::SourceSide, KIO::StatBasic);
+        KIO::StatJob *job = KIO::stat(url, KIO::StatJob::SourceSide, KIO::StatBasic);
         KJobWidgets::setWindow(job, this);
         if (job->exec()) {
             KIO::UDSEntry e = job->statResult();
@@ -754,7 +754,7 @@ void MainWindow::setFullScreen(bool isFullScreen)
         if (!m_FullScreenHandler)
             m_FullScreenHandler = new FullScreenToolBarHandler(this);
     } else {
-        action("fullscreen")->setEnabled(videoWindow()->state() == Phonon::PlayingState || videoWindow()->state() == Phonon::PausedState);
+        action(QStringLiteral("fullscreen"))->setEnabled(videoWindow()->state() == Phonon::PlayingState || videoWindow()->state() == Phonon::PausedState);
         delete m_FullScreenHandler;
         m_FullScreenHandler = nullptr;
     }
@@ -778,7 +778,7 @@ void MainWindow::aboutToShowMenu()
     TheStream::aspectRatioAction()->setChecked(true);
     {
         const int subId = TheStream::subtitleChannel();
-        const QList<QAction *> subs = action("subtitle_channels_menu")->menu()->actions();
+        const QList<QAction *> subs = action(QStringLiteral("subtitle_channels_menu"))->menu()->actions();
         qDebug() << "subtitle #" << subId << " is going to be checked";
         for (QAction *subAction : subs) {
             if (subAction->property(TheStream::CHANNEL_PROPERTY).toInt() == subId) {
@@ -790,7 +790,7 @@ void MainWindow::aboutToShowMenu()
     }
     {
         const int audioId = TheStream::audioChannel();
-        const QList<QAction *> audios = action("audio_channels_menu")->menu()->actions();
+        const QList<QAction *> audios = action(QStringLiteral("audio_channels_menu"))->menu()->actions();
         qDebug() << "audio #" << audioId << " is going to be checked";
         for (QAction *audioAction : audios) {
             if (audioAction->property(TheStream::CHANNEL_PROPERTY).toInt() == audioId) {
@@ -824,7 +824,7 @@ void MainWindow::keyPressEvent(QKeyEvent *e)
         engine()->relativeSeek(5000);
         break;
     case Qt::Key_Escape:
-        action("fullscreen")->setChecked(false);
+        action(QStringLiteral("fullscreen"))->setChecked(false);
     default:;
     }
 }
@@ -858,8 +858,19 @@ void MainWindow::inhibitPowerSave()
     }
     // TODO: inhibit screen sleep. No viable API found.
     // https://git.reviewboard.kde.org/r/129651
-    if (!m_stopScreenSaver && TheStream::hasVideo())
-        m_stopScreenSaver = new KNotificationRestrictions(KNotificationRestrictions::ScreenSaver, i18nc("Notification inhibition reason", "playing a video"));
+    if (TheStream::hasVideo()) {
+        QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                              QStringLiteral("/ScreenSaver"),
+                                                              QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                              QStringLiteral("Inhibit"));
+        message << QGuiApplication::desktopFileName();
+        message << i18nc("Notification inhibition reason", "Playing a video");
+        QDBusReply<uint> reply = QDBusConnection::sessionBus().call(message);
+        if (reply.isValid()) {
+            m_screensaverDisableCookie = reply.value();
+            return;
+        }
+    }
 }
 
 void MainWindow::releasePowerSave()
@@ -871,8 +882,17 @@ void MainWindow::releasePowerSave()
     }
 
     // stop disabling screensaver
-    delete m_stopScreenSaver; // It is always 0, I have been careful.
-    m_stopScreenSaver = nullptr;
+    if (m_screensaverDisableCookie.has_value()) {
+        QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                              QStringLiteral("/ScreenSaver"),
+                                                              QStringLiteral("org.freedesktop.ScreenSaver"),
+                                                              QStringLiteral("UnInhibit"));
+        message << static_cast<uint>(m_screensaverDisableCookie.value());
+        m_screensaverDisableCookie = {};
+        if (QDBusConnection::sessionBus().send(message)) {
+            return;
+        }
+    }
 }
 
 QMenu *MainWindow::menu(const char *name)
@@ -911,8 +931,8 @@ void MainWindow::updateTitleBarText()
         }                                                                                                                                                      \
     }
 
-CHANNELS_CHANGED(subChannelsChanged, "subtitle_channels_menu")
-CHANNELS_CHANGED(audioChannelsChanged, "audio_channels_menu")
+CHANNELS_CHANGED(subChannelsChanged, QStringLiteral("subtitle_channels_menu"))
+CHANNELS_CHANGED(audioChannelsChanged, QStringLiteral("audio_channels_menu"))
 #undef CHANNELS_CHANGED
 
 /// Convenience class for other classes that need access to the actionCollection
@@ -949,7 +969,7 @@ bool MainWindow::isFresh()
 void MainWindow::contextMenuEvent(QContextMenuEvent *event)
 {
     QMenu menu;
-    qobject_cast<KHamburgerMenu *>(action("hamburger_menu"))->addToMenu(&menu);
+    qobject_cast<KHamburgerMenu *>(action(QStringLiteral("hamburger_menu")))->addToMenu(&menu);
     if (menu.isEmpty()) {
         return;
     }
